
/* =====================================================================================================


This do file replicates poverty measures in Chapter 1.

    - File: Do file to create analysis data
	- Purpose: Generate fata files from raw data for final analysis


- Raw Data Inputs:
	--------------
	[ ] Pov_Ineq.xslx 			--  Poverty Inequality Measures full metadata 
	
- Analysis Data Outputs
    --------------
	gini.xslx                       --  Gini indices for countries in the first and the most recent years
	inclusive_growth.xslx           --  Measures of inclusive growth for countries in the first and the most recent years 

	
  ===================================================================================================== */
*	************************************************************************
*	A. Upload the data
*	************************************************************************

* change path here
// cd "path_to_replication_package"


************************************************************************* 
* Gini Indices for African countries **


*latest_year is the most recent year available for any given country
*first_year is the first year available for any given country


* Data

import excel ".../EDAR_data/Pov_Ineq.xlsx", sheet("poverty_inequality_Africa") firstrow, clear


*keep data from 2000+, except for Algeria where data for first year is 1995, as there is one survey estimate after 2000.

keep if year >= 2000 | c3 == "DZA"
drop if c3 == "DZA" & year == 1988

bysort c3: egen latest_year = max(year)
gen latest_yearD = (year==latest_year)
bysort c3: egen first_year = min(year)
gen first_yearD = (year==first_year)
drop if latest_yearD == first_yearD

keep country c3 year Giniindex region_un_sub latest_year latest_yearD first_year 

rename Giniindex GINI_
drop year 

destring GINI_, replace

reshape wide GINI_, i(c3) j(latest_yearD)
gen Diff_Gini = GINI_1 - GINI_0
gen decrease_Gini = (Diff_Gini<0)

order country c3 region_un_sub first_year GINI_0 latest_year GINI_1 Diff_Gini decrease_Gini

export excel using ".../EDAR_data/processed data/gini.xlsx", firstrow(variables) replace

************************************************************************

/* Measuring Inclusive Growth 

the decile shares can be used to compute inclusive growth

*/

import excel ".../EDAR_data/Pov_Ineq.xlsx", sheet("poverty_inequality_Africa") firstrow, clear

keep if year >= 2000 | c3 == "DZA"
drop if c3 == "DZA" & year == 1988

bysort c3: egen latest_year = max(year)
gen latest_yearD = (year==latest_year)
bysort c3: egen first_year = min(year)
gen first_yearD = (year==first_year)

drop if latest_yearD == first_yearD

keep country c3 year Giniindex region_un_sub latest_year latest_yearD first_year d1 - d10 Mean Median Population Headcount

foreach var of varlist Mean - d10 {
                destring `var', replace
        }

forvalues num = 1/10 {
        gen D`num' = Mean * d`num'
        }

drop d1 - d10

foreach var of varlist Mean - Population D1 - D10 {
                rename `var' `var'_
        }

drop year

reshape wide Mean_ - Population D1_ - D10_, i(c3) j(latest_yearD)

** calculate average growth rate **		

gen g_mean = (Mean_1/Mean_0)^(1/(latest_year - first_year)) -1
replace g_mean = 100 * g_mean	

** calculation of the growth rate in income of the decile (d) between the years t-1= first_year and t=latest_year is **

forvalues num = 1/10 {
        gen g`num' = (D`num'_1/D`num'_0)^(1/(latest_year - first_year)) -1
        }
		
forvalues num = 1/10 {
        replace g`num' = 100 * g`num'
        }

********************** 1 : Separate poverty headcount into integer and decimal **************************

** Headcount  is  the  poverty  headcount  (calculated  at  the  poverty  line  of  $1.9  per  day  (purchasing  power parity)) **

gen H_0 = Headcount_0/10
gen H_int_0 = int(H_0)
gen Dec_0 = H_0 - H_int_0


*********************** 2 : Calculate the area under Growth Incidence Curve using rectangle method *********************************************
local i = 1
local j = 0
gen area = 0

while `i' < 10 {
   gen G_`i' = 10* g`i' + area
   replace area = G_`i'
   local j = `i' + 1
   gen DEC_`i' = 10 * Dec_0 * g`j'
   local i = `i' + 1
   }
  drop area
 
********************* 3 : Calculate Pro-poor Growth Rate ******************* 

gen PPGR = 10 * Dec_0 * g1 / Headcount_0 if H_int_0 == 0
local i = 1
while `i' < 10 {
   replace PPGR = (G_`i' + DEC_`i') / Headcount_0 if H_int_0 == `i'
   local i = `i' + 1
   }

gen Incl_Gr_Abs = (PPGR > 0) 
gen Incl_Gr_Rel = (PPGR > g_mean)

**********************************************
** variation in poverty headcount**
gen Diff_H = Headcount_1 - Headcount_0
gen decrease_H = (Diff_H<0)

keeporder country c3 region_un_sub first_year Mean_0 Median_0 Headcount_0 latest_year Mean_1 Median_1 Headcount_1 PPGR g_mean Incl_Gr_Abs Incl_Gr_Rel g1 - g10 Diff_H decrease_H

export excel using ".../EDAR_data/processed data/inclusive_growth.xlsx", firstrow(variables) replace
